fnss.traffic.eventscheduling.EventSchedule.pop — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »

# fnss.traffic.eventscheduling.EventSchedule.pop

`EventSchedule.` `pop`(i)

  Remove from the schedule the event in a specific position

  Parameters : | i : int The index of the event to pop
  Returns : | event : tuple (time, event) The event popped from the schedule

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »